Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(365)

Unified Diff: chrome/browser/chromeos/gdata/drive_file_system.h

Issue 10919093: Rename GDataUplaoder to DriveUploader (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix after rebase Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/gdata/drive_file_system.h
diff --git a/chrome/browser/chromeos/gdata/drive_file_system.h b/chrome/browser/chromeos/gdata/drive_file_system.h
index a557e0bb9a1d1e4c9c88511e5d67b0d1fe4ec32c..65293c17d1518179813379bebb0734fa577508f6 100644
--- a/chrome/browser/chromeos/gdata/drive_file_system.h
+++ b/chrome/browser/chromeos/gdata/drive_file_system.h
@@ -32,8 +32,8 @@ namespace gdata {
class DriveFunctionRemove;
class DriveServiceInterface;
+class DriveUploaderInterface;
class DriveWebAppsRegistryInterface;
-class GDataUploaderInterface;
class GDataWapiFeedLoader;
struct UploadFileInfo;
@@ -45,7 +45,7 @@ class DriveFileSystem : public DriveFileSystemInterface,
DriveFileSystem(Profile* profile,
DriveCache* cache,
DriveServiceInterface* drive_service,
- GDataUploaderInterface* uploader,
+ DriveUploaderInterface* uploader,
DriveWebAppsRegistryInterface* webapps_registry,
base::SequencedTaskRunner* blocking_task_runner);
virtual ~DriveFileSystem();
@@ -746,7 +746,7 @@ class DriveFileSystem : public DriveFileSystemInterface,
int64* file_size);
// Part of UpdateFileByResourceId().
// Callback for GDataRootDirectory::GetEntryInfoByResourceId.
// |callback| must not be null.
void OnGetFileCompleteForUpdateFileByEntry(
const FileOperationCallback& callback,
@@ -757,7 +757,7 @@ class DriveFileSystem : public DriveFileSystemInterface,
scoped_ptr<DriveEntryProto> entry_proto);
// Part of UpdateFileByResourceId().
- // Called when GDataUploader::UploadUpdatedFile() is completed for
+ // Called when DriveUploader::UploadUpdatedFile() is completed for
// UpdateFileByResourceId().
// |callback| must not be null.
void OnUpdatedFileUploaded(const FileOperationCallback& callback,
@@ -914,7 +914,7 @@ class DriveFileSystem : public DriveFileSystemInterface,
DriveCache* cache_;
// The uploader owned by DriveSystemService.
- GDataUploaderInterface* uploader_;
+ DriveUploaderInterface* uploader_;
// The document service owned by DriveSystemService.
DriveServiceInterface* drive_service_;
« no previous file with comments | « chrome/browser/chromeos/gdata/drive_download_observer.cc ('k') | chrome/browser/chromeos/gdata/drive_file_system.cc » ('j') | no next file with comments »
@@ -746,7 +746,7 @@ class DriveFileSystem : public DriveFileSystemInterface,
int64* file_size);
// Part of UpdateFileByResourceId().
- // Callback for GDataRootDirectory::GetEntryInfoByResourceId.
+ // Callback for DriveRootDirectory::GetEntryInfoByResourceId.
// |callback| must not be null.
void OnGetFileCompleteForUpdateFileByEntry(

Powered by Google App Engine
This is Rietveld 408576698